@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..3\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use PDF::Template;
 $loaded = 1;
@@ -18,6 +18,13 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
+
+my @fnames = qw ( Bert Ernie Kermit Beavis Butthead Cornholio Ren Cartman Kenny Drew );
+my @lnames = qw ( Washington Lincoln Bush Hoover Adams Kennedy Eisenhower Garfield Nixon Reagan );
+
+
+### Test 2
+
 my $rpt = new PDF::Template(FILENAME=>'examples/t2.xml');
 
 
@@ -29,3 +36,25 @@ $rpt->param( { TITLE=>'blah blah',
 $rpt->param( DATA=> [ {ORD=>'first'}, {ORD=>'second'}, {ORD=>'third'} ] );
 
 $rpt->write_file("examples/t2.pdf");
+print "ok 2\n";
+
+
+### Test 3 : Loop
+
+my @d3;
+for (my $i=0; $i<100; $i++)
+{
+   my %h;
+   $h{LNAME} = $lnames[rand(10)];
+   $h{FNAME} = $fnames[rand(10)];
+   $h{VAL} = $i;
+   push @d3,\%h;
+}
+
+my $t3 = new PDF::Template(FILENAME=>'examples/t3_loop.xml');
+$t3->param(DATA=>\@d3);
+
+$t3->write_file("examples/t3_loop.pdf");
+
+print "ok 3\n";
+
